@@ -1257,7 +1257,7 @@ def _start(client, bot):
 			def remember(text):
 				bot._nowcmd=text
 				return True
-			if any(cmd in message.content[:len(max(bot._cmds, key=len))] and remember(cmd) for cmd in bot._codes["command"]):
+			if any([message.content[:len(max(bot._cmds, key=len))].startswith(await replaces(bot._codes["command"][cmd]["prefix"], message, message.guild, message.content, message, {}, 0, message.author)+await replaces(bot._codes["command"][cmd]["name"], message, message.guild, message.content, message, {}, 0, message.author)) and remember(cmd) for cmd in bot._codes["command"]]):
 				await use(message, bot._nowcmd, bot._codes["command"][bot._nowcmd]["prefix"]+bot._codes["command"][bot._nowcmd]["name"], "command")
 	if bot._self:
 		client.run(bot._token, bot=False)
